==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/devices/kotlin/inputs/FallbackRoutePropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.devices.kotlin.inputs

import com.pulumi.azurenative.devices.inputs.FallbackRoutePropertiesArgs.builder
import com.pulumi.azurenative.devices.kotlin.enums.RoutingSource
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The properties of the fallback route. IoT Hub uses these properties when it routes messages to the fallback endpoint.
 * @property condition The condition which is evaluated in order to apply the fallback route. If the condition is not provided it will evaluate to true by default. For grammar, See: https://docs.microsoft.com/azure/iot-hub/iot-hub-devguide-query-language
 * @property endpointNames The list of endpoints to which the messages that satisfy the condition are routed to. Currently only 1 endpoint is allowed.
 * @property isEnabled Used to specify whether the fallback route is enabled.
 * @property name The name of the route. The name can only include alphanumeric characters, periods, underscores, hyphens, has a maximum length of 64 characters, and must be unique.
 * @property source The source to which the routing rule is to be applied to. For example, DeviceMessages
 */
public data class FallbackRoutePropertiesArgs(
    public val condition: Output<String>? = null,
    public val endpointNames: Output<List<String>>,
    public val isEnabled: Output<Boolean>,
    public val name: Output<String>? = null,
    public val source: Output<Either<String, RoutingSource>>,
) : ConvertibleToJava<com.pulumi.azurenative.devices.inputs.FallbackRoutePropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.devices.inputs.FallbackRoutePropertiesArgs =
        com.pulumi.azurenative.devices.inputs.FallbackRoutePropertiesArgs.builder()
            .condition(condition?.applyValue({ args0 -> args0 }))
            .endpointNames(endpointNames.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .isEnabled(isEnabled.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .source(
                source.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [FallbackRoutePropertiesArgs].
 */
@PulumiTagMarker
public class FallbackRoutePropertiesArgsBuilder internal constructor() {
    private var condition: Output<String>? = null

    private var endpointNames: Output<List<String>>? = null

    private var isEnabled: Output<Boolean>? = null

    private var name: Output<String>? = null

    private var source: Output<Either<String, RoutingSource>>? = null

    /**
     * @param value The condition which is evaluated in order to apply the fallback route. If the condition is not provided it will evaluate to true by default. For grammar, See: https://docs.microsoft.com/azure/iot-hub/iot-hub-devguide-query-language
     */
    @JvmName("sdmmbpyvhkffnvgr")
    public suspend fun condition(`value`: Output<String>) {
        this.condition = value
    }

    /**
     * @param value The list of endpoints to which the messages that satisfy the condition are routed to. Currently only 1 endpoint is allowed.
     */
    @JvmName("wpyvmxiyovmwfefl")
    public suspend fun endpointNames(`value`: Output<List<String>>) {
        this.endpointNames = value
    }

    @JvmName("kguifliighmfpwed")
    public suspend fun endpointNames(vararg values: Output<String>) {
        this.endpointNames = Output.all(values.asList())
    }

    /**
     * @param values The list of endpoints to which the messages that satisfy the condition are routed to. Currently only 1 endpoint is allowed.
     */
    @JvmName("kcsjywjuyvlnlkcg")
    public suspend fun endpointNames(values: List<Output<String>>) {
        this.endpointNames = Output.all(values)
    }

    /**
     * @param value Used to specify whether the fallback route is enabled.
     */
    @JvmName("yxdirhxnvaswkdta")
    public suspend fun isEnabled(`value`: Output<Boolean>) {
        this.isEnabled = value
    }

    /**
     * @param value The name of the route. The name can only include alphanumeric characters, periods, underscores, hyphens, has a maximum length of 64 characters, and must be unique.
     */
    @JvmName("uxcmsxclolbexgio")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The source to which the routing rule is to be applied to. For example, DeviceMessages
     */
    @JvmName("quyhyaxvqvyjhnwq")
    public suspend fun source(`value`: Output<Either<String, RoutingSource>>) {
        this.source = value
    }

    /**
     * @param value The condition which is evaluated in order to apply the fallback route. If the condition is not provided it will evaluate to true by default. For grammar, See: https://docs.microsoft.com/azure/iot-hub/iot-hub-devguide-query-language
     */
    @JvmName("qjwsbvewcqmbjylr")
    public suspend fun condition(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.condition = mapped
    }

    /**
     * @param value The list of endpoints to which the messages that satisfy the condition are routed to. Currently only 1 endpoint is allowed.
     */
    @JvmName("lapumetsliugkxml")
    public suspend fun endpointNames(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endpointNames = mapped
    }

    /**
     * @param values The list of endpoints to which the messages that satisfy the condition are routed to. Currently only 1 endpoint is allowed.
     */
    @JvmName("uhxddwbiwvuploul")
    public suspend fun endpointNames(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endpointNames = mapped
    }

    /**
     * @param value Used to specify whether the fallback route is enabled.
     */
    @JvmName("tmvqtsbdyhwftyaq")
    public suspend fun isEnabled(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.isEnabled = mapped
    }

    /**
     * @param value The name of the route. The name can only include alphanumeric characters, periods, underscores, hyphens, has a maximum length of 64 characters, and must be unique.
     */
    @JvmName("wimmxonhlromedro")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The source to which the routing rule is to be applied to. For example, DeviceMessages
     */
    @JvmName("sbmiirvyugojbfxq")
    public suspend fun source(`value`: Either<String, RoutingSource>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.source = mapped
    }

    /**
     * @param value The source to which the routing rule is to be applied to. For example, DeviceMessages
     */
    @JvmName("ahyeugatiljtitli")
    public fun source(`value`: String) {
        val toBeMapped = Either.ofLeft<String, RoutingSource>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.source = mapped
    }

    /**
     * @param value The source to which the routing rule is to be applied to. For example, DeviceMessages
     */
    @JvmName("ystkibshguvmrela")
    public fun source(`value`: RoutingSource) {
        val toBeMapped = Either.ofRight<String, RoutingSource>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.source = mapped
    }

    internal fun build(): FallbackRoutePropertiesArgs = FallbackRoutePropertiesArgs(
        condition = condition,
        endpointNames = endpointNames ?: throw PulumiNullFieldException("endpointNames"),
        isEnabled = isEnabled ?: throw PulumiNullFieldException("isEnabled"),
        name = name,
        source = source ?: throw PulumiNullFieldException("source"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/devices/kotlin/inputs/FallbackRoutePropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.devices.kotlin.inputs

import com.pulumi.azurenative.devices.inputs.FallbackRoutePropertiesArgs.builder
import com.pulumi.azurenative.devices.kotlin.enums.RoutingSource
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The properties of the fallback route. IoT Hub uses these properties when it routes messages to the fallback endpoint.
 * @property condition The condition which is evaluated in order to apply the fallback route. If the condition is not provided it will evaluate to true by default. For grammar, See: https://docs.microsoft.com/azure/iot-hub/iot-hub-devguide-query-language
 * @property endpointNames The list of endpoints to which the messages that satisfy the condition are routed to. Currently only 1 endpoint is allowed.
 * @property isEnabled Used to specify whether the fallback route is enabled.
 * @property name The name of the route. The name can only include alphanumeric characters, periods, underscores, hyphens, has a maximum length of 64 characters, and must be unique.
 * @property source The source to which the routing rule is to be applied to. For example, DeviceMessages
 */
public data class FallbackRoutePropertiesArgs(
    public val condition: Output<String>? = null,
    public val endpointNames: Output<List<String>>,
    public val isEnabled: Output<Boolean>,
    public val name: Output<String>? = null,
    public val source: Output<Either<String, RoutingSource>>,
) : ConvertibleToJava<com.pulumi.azurenative.devices.inputs.FallbackRoutePropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.devices.inputs.FallbackRoutePropertiesArgs =
        com.pulumi.azurenative.devices.inputs.FallbackRoutePropertiesArgs.builder()
            .condition(condition?.applyValue({ args0 -> args0 }))
            .endpointNames(endpointNames.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .isEnabled(isEnabled.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .source(
                source.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [FallbackRoutePropertiesArgs].
 */
@PulumiTagMarker
public class FallbackRoutePropertiesArgsBuilder internal constructor() {
    private var condition: Output<String>? = null

    private var endpointNames: Output<List<String>>? = null

    private var isEnabled: Output<Boolean>? = null

    private var name: Output<String>? = null

    private var source: Output<Either<String, RoutingSource>>? = null

    /**
     * @param value The condition which is evaluated in order to apply the fallback route. If the condition is not provided it will evaluate to true by default. For grammar, See: https://docs.microsoft.com/azure/iot-hub/iot-hub-devguide-query-language
     */
    @JvmName("lfwjkxitwkjuubuh")
    public suspend fun condition(`value`: Output<String>) {
        this.condition = value
    }

    /**
     * @param value The list of endpoints to which the messages that satisfy the condition are routed to. Currently only 1 endpoint is allowed.
     */
    @JvmName("deghgdvjoicuoakr")
    public suspend fun endpointNames(`value`: Output<List<String>>) {
        this.endpointNames = value
    }

    @JvmName("ltfmtrvypmaynmyr")
    public suspend fun endpointNames(vararg values: Output<String>) {
        this.endpointNames = Output.all(values.asList())
    }

    /**
     * @param values The list of endpoints to which the messages that satisfy the condition are routed to. Currently only 1 endpoint is allowed.
     */
    @JvmName("ylfvwnpldrdqewun")
    public suspend fun endpointNames(values: List<Output<String>>) {
        this.endpointNames = Output.all(values)
    }

    /**
     * @param value Used to specify whether the fallback route is enabled.
     */
    @JvmName("bwicaummdjcxofio")
    public suspend fun isEnabled(`value`: Output<Boolean>) {
        this.isEnabled = value
    }

    /**
     * @param value The name of the route. The name can only include alphanumeric characters, periods, underscores, hyphens, has a maximum length of 64 characters, and must be unique.
     */
    @JvmName("gmvkgsubktpfauih")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The source to which the routing rule is to be applied to. For example, DeviceMessages
     */
    @JvmName("aswuslkoasaxbsiv")
    public suspend fun source(`value`: Output<Either<String, RoutingSource>>) {
        this.source = value
    }

    /**
     * @param value The condition which is evaluated in order to apply the fallback route. If the condition is not provided it will evaluate to true by default. For grammar, See: https://docs.microsoft.com/azure/iot-hub/iot-hub-devguide-query-language
     */
    @JvmName("bxpbqhtdksxrhvak")
    public suspend fun condition(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.condition = mapped
    }

    /**
     * @param value The list of endpoints to which the messages that satisfy the condition are routed to. Currently only 1 endpoint is allowed.
     */
    @JvmName("pnfeelqaiptfqyym")
    public suspend fun endpointNames(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endpointNames = mapped
    }

    /**
     * @param values The list of endpoints to which the messages that satisfy the condition are routed to. Currently only 1 endpoint is allowed.
     */
    @JvmName("nkaqsxhbxrtffoyi")
    public suspend fun endpointNames(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endpointNames = mapped
    }

    /**
     * @param value Used to specify whether the fallback route is enabled.
     */
    @JvmName("touyoqbyrvqxgfli")
    public suspend fun isEnabled(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.isEnabled = mapped
    }

    /**
     * @param value The name of the route. The name can only include alphanumeric characters, periods, underscores, hyphens, has a maximum length of 64 characters, and must be unique.
     */
    @JvmName("aftgtiqgtfkjkbdd")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The source to which the routing rule is to be applied to. For example, DeviceMessages
     */
    @JvmName("pjnldohpmxajmtkv")
    public suspend fun source(`value`: Either<String, RoutingSource>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.source = mapped
    }

    /**
     * @param value The source to which the routing rule is to be applied to. For example, DeviceMessages
     */
    @JvmName("oncdjljqiygnrdex")
    public fun source(`value`: String) {
        val toBeMapped = Either.ofLeft<String, RoutingSource>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.source = mapped
    }

    /**
     * @param value The source to which the routing rule is to be applied to. For example, DeviceMessages
     */
    @JvmName("dwavidhvmcxvyygj")
    public fun source(`value`: RoutingSource) {
        val toBeMapped = Either.ofRight<String, RoutingSource>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.source = mapped
    }

    internal fun build(): FallbackRoutePropertiesArgs = FallbackRoutePropertiesArgs(
        condition = condition,
        endpointNames = endpointNames ?: throw PulumiNullFieldException("endpointNames"),
        isEnabled = isEnabled ?: throw PulumiNullFieldException("isEnabled"),
        name = name,
        source = source ?: throw PulumiNullFieldException("source"),
    )
}
